@@ -1,5 +1,5 @@
 /*
- Copyright (C) 2007 Christian Dywan <christian@twotoasts.de>
+ Copyright (C) 2007-2009 Christian Dywan <christian@twotoasts.de>
 
  This library is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
@@ -9,11 +9,17 @@
  See the file COPYING for the full license text.
 */
 
-#ifndef __KATZE__
-#define __KATZE__
+#ifndef __KATZE_H__
+#define __KATZE_H__
 
+#include "katze-http-auth.h"
+#include "katze-http-cookies.h"
 #include "katze-throbber.h"
 #include "katze-utils.h"
-#include "katze-xbel.h"
+#include "katze-item.h"
+#include "katze-array.h"
+#include "katze-arrayaction.h"
+#include "katze-separatoraction.h"
+#include "katze-net.h"
 
 #endif /* __KATZE_H__ */
